@@ -229,9 +229,9 @@ filt_plot_2d <- function(raw.data,fixation.data, plot.window = c(NA, NA), raw.co
 
 
 
-#' Plot fixations in 2D space overlaied on a stimulus image
+#' Plot fixations in 2D space on a stimulus image (with visible x and y axis labels and ticks)
 #' @description This function plots and returns a ggplot2 figure showing fixations on a background with one or multiple images, typically the stimuli. Data can
-#' represent one or multiple participants
+#' represent one or multiple participants. If you want a plot without visible axis labels and ticks, use static_plot_minimal
 #' The interval to plot is defined by sample numbers. Fixations must have the variables x, y, and onset. The function is tested with .jpg-images. If paths to multiple images
 #' are given, all will be displayed. Fixations are shown on a white background if no background images are defined
 #' @param gazedata Data frame with fixation data which must include columns for x and y coordinates as well as the
@@ -256,7 +256,8 @@ filt_plot_2d <- function(raw.data,fixation.data, plot.window = c(NA, NA), raw.co
 #' @param connect.lines If TRUE, gaze coordinates are connected with lines
 #' @param verbose If TRUE, the resulting figure is displayed automatically
 #' @param gazepoint.size Size of the circle illustrating the point of gaze
-#' @param id_color_map A ggplot color map specifying a color to plot for each id. ids should match the variable id'in the gazedata matrix. Set to NA to assign values automatically.
+#' @param id_color_map A ggplot color map specifying a color to plot for each id. ids should match the variable id in the gazedata matrix. Set to NA to assign values automatically.
+#' For example, the code cm <- setNames("darkblue", ""example.id") creates the color map cm which will plot all data points in gazedata where the variable id == "example.id" in dark blue
 #' @return a ggplot of raw and fixated values plotted on the y axis and sample number on the x axis
 
 static_plot <- function(gazedata, xres = 1920, yres = 1080, plot.onset, plot.offset, background.images = NA, show.legend = TRUE, group.by = NA,
@@ -266,7 +267,7 @@ static_plot <- function(gazedata, xres = 1920, yres = 1080, plot.onset, plot.off
 
   gazedata <- filter(gazedata, .data$onset >= plot.onset, .data$offset <= plot.offset)
   gazedata$id <- factor(gazedata$id)
-  gazedata <- gazedata %>% group_by(id)
+  gazedata <- gazedata %>% group_by(.data$id)
 
   if (!is.na(group.by)) {
     message(paste0("Splitting plot by variable ", group.by))
@@ -776,3 +777,127 @@ fixation_plot_ts <- function(data_in, plot.window = c(NA, NA), x.index.var ="tim
 
   return(g)
 }
+
+
+#' Plot fixations in 2D space on a stimulus image (minimalistic plot)
+#' @description This function plots and returns a ggplot2 figure showing fixations on a background with one or multiple images, typically the stimuli. Data can
+#' represent one or multiple participants. The output isminimalistic plot without x and y axis ticks or labels. If you want a plot with these features, use
+#' static_plot with the same input arguments
+#' The interval to plot is defined by sample numbers. Fixations must have the variables x, y, and onset. The function is tested with .jpg-images. If paths to multiple images
+#' are given, all will be displayed. Fixations are shown on a white background if no background images are defined
+#' @param gazedata Data frame with fixation data which must include columns for x and y coordinates as well as the
+#' variable onset which indicates the onset of the fixation. If the categorical or factor variable id is included, separate colors will represent each participant. Make sure the onset variables match the timing  the plot.onset and plot.offset input.
+#' @param background.images data frame with background images to use as background. The data frame must include the variables min.x, min.y, max.x, and max.y variables representing
+#' where the images should be placed on the background and the variable path specifying a full file path.
+#' #Example:
+#' \code{background.images <- data.frame(
+#'        path = "my_image.jpg",
+#'        min.x = 1,
+#'        min.y = 1,
+#'        max.x = 200.
+#'        max.y = 200)}
+#'
+#' @param xres horizontal resolution of the screen or area to plot on. Default 1920
+#' @param yres vertical resolution of the screen or area to plot on. Default 1080
+#' @param plot.onset Onset of the interval in the gaze_data$onset variable to plot in the same unit, typically milliseconds
+#' @param plot.offset Offset of the interval in the gaze_data$onset variable to plot in the same unit, typically milliseconds
+#' @param show.legend If TRUE, show values in "id" in legend
+#' @param group.by If not NA, plot each level in the variable in a separate panel. For example group.by \code{=} "group" returns a separate panel for each group and group.by \code{=}"id"
+#' returns a separate panel for each id.
+#' @param connect.lines If TRUE, gaze coordinates are connected with lines
+#' @param verbose If TRUE, the resulting figure is displayed automatically
+#' @param gazepoint.size Size of the circle illustrating the point of gaze
+#' @param id_color_map A ggplot color map specifying a color to plot for each id. ids should match the variable id in the gazedata matrix. Set to NA to assign values automatically.
+#' For example, the code cm <- setNames("darkblue", ""example.id") creates the color map cm which will plot all data points in gazedata where the variable id == "example.id" in dark blue
+#' @return a ggplot of raw and fixated values plotted on the y axis and sample number on the x axis
+
+
+static_plot_minimal <- function(gazedata, xres = 1920, yres = 1080, plot.onset, plot.offset, background.images = NA, show.legend = TRUE, group.by = NA,
+                                gazepoint.size = 4, id_color_map =NA, connect.lines = TRUE, verbose = TRUE) {
+
+  if (!"id" %in% names(gazedata)){gazedata$id <-"1"}
+
+  gazedata <- filter(gazedata, .data$onset >= plot.onset, .data$offset <= plot.offset)
+  gazedata$id <- factor(gazedata$id)
+  gazedata <- gazedata %>% group_by(.data$id)
+
+  if (!is.na(group.by)) {
+    message(paste0("Splitting plot by variable ", group.by))
+    gazedata$group <- gazedata[[group.by]]
+  }
+
+  if (is.data.frame(background.images)){ #Rescale from pixels to proportion of the screen
+    background.images$min.x <- background.images$min.x/xres
+    background.images$min.y <- background.images$min.y/yres
+    background.images$max.x <- background.images$max.x/xres
+    background.images$max.y <- background.images$max.y/yres
+
+    #Use this aesthetic in all plots
+    plot.aes <- aes(x = .data$x, y = .data$y, group = .data$id, colour = .data$id)
+
+    #Create an empty white image
+    background <- ggplot()+xlim(1,xres) +ylim(yres,1)+ coord_fixed(expand = FALSE)+
+      theme_void()
+
+    # Add  smulus images to background
+    for (i in dim(background.images[1])){
+      im <- jpeg::readJPEG(background.images$path[i], native = TRUE)
+      background <- background+  inset_element(p = im, left = background.images$min.x[i], right = background.images$max.x[i],
+                                               bottom = background.images$min.y[i], top = background.images$max.y[i])
+
+    }
+    #Save the background as a temporary file with pixel measures corresponding to screen size
+    t <- tempdir()
+    temp.path <- paste0(t, "\\background_temp.jpg")
+    ggplot2::ggsave(temp.path, width = xres, height = yres, units = "px", limitsize = FALSE, dpi =1)
+    im <- jpeg::readJPEG(temp.path)
+
+    #Plot on the stimulus background
+    suppressMessages(
+      g <- ggplot(data = gazedata, aes(x = .data$x, y = .data$y, group = .data$id, colour = .data$id))+
+        scale_y_reverse(limits = c(yres,0),  expand = c(0, 0), breaks = NULL, name = NULL)+
+        scale_x_continuous(limits = c(0,xres),  expand = c(0, 0), breaks = NULL, name =NULL)+
+        ggpubr::background_image(im)+theme(panel.background = element_rect(fill = "white", color = "white"))+
+        geom_point(size =gazepoint.size, show.legend = show.legend)
+
+
+
+    )
+
+
+
+  } else {
+    #Plot without background if no images are passed
+    suppressMessages(
+      g <- ggplot(data = gazedata, aes(x = .data$x, y = .data$y, group = .data$id, colour = .data$id))+
+        scale_y_reverse(limits = c(yres,0),  expand = c(0, 0), breaks = NULL, name = NULL)+
+        scale_x_continuous(limits = c(0,xres),  expand = c(0, 0), breaks = NULL, name =NULL)+
+        geom_point(size =gazepoint.size, show.legend = show.legend)
+
+
+    )
+
+  }
+
+  if(connect.lines == TRUE){
+    g <- g+ geom_line(show.legend = show.legend)
+
+  }
+
+  #Match the colors to specific IDs
+  if (sum(!is.na(id_color_map))>0) {
+    g <- g+scale_color_manual(values = id_color_map)}
+  #Split the plot in different panels if the group.by argument is not NA
+  if (!is.na(group.by)) {
+    g <- g + facet_wrap(vars(.data$group))
+
+
+  }
+  if (verbose == TRUE){
+    suppressMessages(
+      print(g)
+    )
+  }
+  return(g)
+}
+
